%%
%% This is file `pl209.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% pl209.dtx  (with options: `pl209')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from pl209.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file pl209.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
%% File: pl209.dtx
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\typeout{Entering pLaTeX 2.09 compatibility mode.}
\input{latex209.def}
\RequirePackage{ptrace}
\let\Rensuji\rensuji
\let\prensuji\rensuji
\def\@footnotemark{\leavevmode
  \ifhmode\edef\@x@sf{\the\spacefactor}\fi
  \ifydir\@makefnmark
  \else\hbox to\z@{\hskip-.25zw\raise2\cht\@makefnmark\hss}\fi
  \ifhmode\spacefactor\@x@sf\fi\relax}
\def\@makefnmark{\hbox{\ifydir $\m@th^{\@thefnmark}$
  \else\hbox{\yoko$\m@th^{\@thefnmark}$}\fi}}
\fontencoding{JY1}
\fontfamily{mc}
\fontsize{10}{15}
\DeclareSymbolFont{mincho}{JY1}{mc}{m}{n}
\DeclareSymbolFont{gothic}{JY1}{gt}{m}{n}
\DeclareSymbolFontAlphabet\mathmc{mincho}
\DeclareSymbolFontAlphabet\mathgt{gothic}
\SetSymbolFont{mincho}{bold}{JY1}{gt}{m}{n}
\jfam\symmincho
\DeclareRobustCommand\mc{%
    \kanjiencoding{\kanjiencodingdefault}%
    \kanjifamily{\mcdefault}%
    \kanjiseries{\kanjiseriesdefault}%
    \kanjishape{\kanjishapedefault}%
    \selectfont\mathgroup\symmincho}
\DeclareRobustCommand\gt{%
    \kanjiencoding{\kanjiencodingdefault}%
    \kanjifamily{\gtdefault}%
    \kanjiseries{\kanjiseriesdefault}%
    \kanjishape{\kanjishapedefault}%
    \selectfont\mathgroup\symgothic}
\DeclareRobustCommand\bf{\normalfont\bfseries\mathgroup\symbold\jfam\symgothic}
\DeclareRobustCommand\roman@normal{%
    \romanencoding{\encodingdefault}%
    \romanfamily{\familydefault}%
    \romanseries{\seriesdefault}%
    \romanshape{\shapedefault}%
    \selectfont\ignorespaces}
\DeclareRobustCommand\rm{\roman@normal\rmfamily\mathgroup\symoperators}
\DeclareRobustCommand\sf{\roman@normal\sffamily\mathgroup\symsans}
\DeclareRobustCommand\sl{\roman@normal\slshape\mathgroup\symslanted}
\DeclareRobustCommand\sc{\roman@normal\scshape\mathgroup\symsmallcaps}
\DeclareRobustCommand\it{\roman@normal\itshape\mathgroup\symitalic}
\DeclareRobustCommand\tt{\roman@normal\ttfamily\mathgroup\symtypewriter}
\DeclareRobustCommand\em{%
  \@nomath\em
  \ifdim \fontdimen\@ne\font>\z@\mc\rm\else\gt\it\fi}
\let\mcfam\symmincho
\let\gtfam\symgothic
\renewcommand\vpt   {\edef\f@size{\@vpt}\rm\mc}
\renewcommand\vipt  {\edef\f@size{\@vipt}\rm\mc}
\renewcommand\viipt {\edef\f@size{\@viipt}\rm\mc}
\renewcommand\viiipt{\edef\f@size{\@viiipt}\rm\mc}
\renewcommand\ixpt  {\edef\f@size{\@ixpt}\rm\mc}
\renewcommand\xpt   {\edef\f@size{\@xpt}\rm\mc}
\renewcommand\xipt  {\edef\f@size{\@xipt}\rm\mc}
\renewcommand\xiipt {\edef\f@size{\@xiipt}\rm\mc}
\renewcommand\xivpt {\edef\f@size{\@xivpt}\rm\mc}
\renewcommand\xviipt{\edef\f@size{\@xviipt}\rm\mc}
\renewcommand\xxpt  {\edef\f@size{\@xxpt}\rm\mc}
\renewcommand\xxvpt {\edef\f@size{\@xxvpt}\rm\mc}
\InputIfFileExists{pl209.cfg}{}{}
\endinput
%%
%% End of file `pl209.def'.
